Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1141)

Unified Diff: media/formats/mp2t/ts_section_pmt.h

Issue 1517473002: Support HLS MPEG2 TS with SAMPLE-AES encryption. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@encryption_scheme
Patch Set: ddorwin comments Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/formats/mp2t/ts_section_pmt.h
diff --git a/media/formats/mp2t/ts_section_pmt.h b/media/formats/mp2t/ts_section_pmt.h
index b5a1dfdf60ed40dee9f99d47dbc0da13d00b8bb6..db1a41b00dce22bef7a4aec752f54a97cd18166e 100644
--- a/media/formats/mp2t/ts_section_pmt.h
+++ b/media/formats/mp2t/ts_section_pmt.h
@@ -8,6 +8,7 @@
#include "base/callback.h"
#include "base/compiler_specific.h"
#include "base/macros.h"
+#include "media/formats/mp2t/descriptors.h"
#include "media/formats/mp2t/ts_section_psi.h"
namespace media {
@@ -15,11 +16,10 @@ namespace mp2t {
class TsSectionPmt : public TsSectionPsi {
public:
// RegisterPesCb::Run(int pes_pid, int stream_type);
// Stream type is defined in
// "Table 2-34 – Stream type assignments" in H.222
// TODO(damienv): add the program number.
- typedef base::Callback<void(int, int)> RegisterPesCb;
+ using RegisterPesCb = base::Callback<
+ void(int pes_pid, int stream_type, const Descriptors& descriptors)>;
explicit TsSectionPmt(const RegisterPesCb& register_pes_cb);
~TsSectionPmt() override;
@@ -15,11 +16,10 @@ namespace mp2t {
class TsSectionPmt : public TsSectionPsi {
public:
- // RegisterPesCb::Run(int pes_pid, int stream_type);
- // Stream type is defined in
- // "Table 2-34 – Stream type assignments" in H.222
+ // |stream_type| is defined in "Table 2-34 – Stream type assignments" in H.222
// TODO(damienv): add the program number.

Powered by Google App Engine
This is Rietveld 408576698